@@ -1,7 +1,7 @@
 /*
     Swephelp
 
-    Copyright 2007-2014 Stanislas Marquis <stnsls@gmail.com>
+    Copyright 2007-2014 Stanislas Marquis <smarquis@astrorigin.ch>
 
     Swephelp is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License as
@@ -21,11 +21,6 @@
 ** @brief swephelp utilities
 */
 
-#ifdef __cplusplus
-extern "C"
-{
-#endif
-
 #include "swhutil.h"
 
 #include <assert.h>
@@ -105,7 +100,4 @@ int swh_set_globals(swh_Globals *glob)
 }
 
 #endif /* SWH_USE_THREADS */
-
-#ifdef __cplusplus
-} /* extern "C" */
-#endif
+/* vi: set fenc=utf-8 ff=unix et sw=4 ts=4 sts=4 : */
